/**
 * \file mcql/core/msrun.cpp
 * \date 24/09/2024
 * \author Olivier Langella
 * \brief msrun model in masschroqlite
 */

/*******************************************************************************
 * Copyright (c) 2024 Olivier Langella
 *<Olivier.Langella@universite-paris-saclay.fr>.
 *
 * This file is part of MassChroQ.
 *
 *     MassChroQ is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     MassChroQ is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with MassChroQ.  If not, see <http://www.gnu.org/licenses/>.
 *
 ******************************************************************************/


#include "msrun.h"
#include <pappsomspp/pappsoexception.h>

namespace mcql
{

MsRun::MsRun(pappso::MsRunReaderSPtr msrun_reader)
  : msp_msRunReader(msrun_reader)
{


  mpa_precursorParser = new PrecursorParser(msp_msRunReader);

  pappso::MsRunReadConfig config;
  config.setNeedPeakList(false);
  config.setMsLevels({2});
  qDebug();
  // msrunA01.get()->readSpectrumCollection(spectrum_list_reader);
  msp_msRunReader.get()->readSpectrumCollection2(config, *mpa_precursorParser);
}

MsRun::MsRun(const MsRun &other)
{
}

MsRun::~MsRun()
{
  delete mpa_precursorParser;
}

pappso::MsRunReaderSPtr &
MsRun::getMsRunReaderSPtr()
{
  return msp_msRunReader;
}

} // namespace mcql

const PrecursorSPtr &
mcql::MsRun::getPrecursorSPtrByScanNumber(std::size_t scan_number) const
{
  return mpa_precursorParser->getPrecursorSPtrByScanNumber(scan_number);
}
const PrecursorSPtr &
mcql::MsRun::getPrecursorSPtrBySpectrumIndex(std::size_t spectrum_index) const
{
  return mpa_precursorParser->getPrecursorSPtrBySpectrumIndex(spectrum_index);
}
