
/**
 * \file mcql/output/quantificationresultodsoutput.h
 * \date 27/09/2024
 * \author Olivier Langella
 * \brief quantification result ods writer for MassChroqLight
 */

/*******************************************************************************
 * Copyright (c) 2024 Olivier Langella
 *<Olivier.Langella@universite-paris-saclay.fr>.
 *
 * This file is part of MassChroQ.
 *
 *     MassChroQ is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 *
 *     MassChroQ is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with MassChroQ.  If not, see <http://www.gnu.org/licenses/>.
 *
 ******************************************************************************/

#pragma once

#include "quantificationresultwriterinterface.h"
#include <odsstream/odsdocwriter.h>
#include <odsstream/odsexception.h>
#include <odsstream/tsvdirectorywriter.h>
#include <QStringList>


namespace mcql
{

class QuantificationResultOdsOutputBase
  : public QuantificationResultWriterInterface
{
  public:
  /**
   * Default constructor
   */
  QuantificationResultOdsOutputBase();

  /**
   * Destructor
   */
  virtual ~QuantificationResultOdsOutputBase();


  virtual void startPeptideMeasurements() override;
  virtual void
  write(const mcql::PeptideMeasurements &peptide_measurements) override;
  virtual void endPeptideMeasurements() override;


  protected:
  CalcWriterInterface *mpa_calcWriterInterface = nullptr;
  QString m_currentSheetName;
};

class QuantificationResultOdsOutput;

typedef std::shared_ptr<QuantificationResultOdsOutput>
  QuantificationResultOdsOutputSp;
/**
 * @todo write docs
 */
class QuantificationResultOdsOutput : public QuantificationResultOdsOutputBase
{
  public:
  /**
   * Default constructor
   */
  QuantificationResultOdsOutput(const QString &ods_file);

  /**
   * Destructor
   */
  virtual ~QuantificationResultOdsOutput();
};


class QuantificationResultTsvOutput;

typedef std::shared_ptr<QuantificationResultTsvOutput>
  QuantificationResultTsvOutputSp;
/**
 * @todo write docs
 */
class QuantificationResultTsvOutput : public QuantificationResultOdsOutputBase
{
  public:
  /**
   * Default constructor
   */
  QuantificationResultTsvOutput(const QString &output_directory);

  /**
   * Destructor
   */
  virtual ~QuantificationResultTsvOutput();
};
} // namespace mcql
